==> kdepim-4.14.2.tar.xz: kdepim-4.14.2/storageservicemanager/storageservicemanagermainwidget.cpp <==
/*
  Copyright (c) 2014 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/


#include "storageservicemanagermainwidget.h"
#include "storageserviceconfigurestoragewidget.h"
#include "storageservicetabwidget.h"

StorageServiceManagerMainWidget::StorageServiceManagerMainWidget(QWidget *parent)
    : QStackedWidget(parent)
{
    mConfigureWidget = new StorageServiceConfigureStorageWidget;
    connect(mConfigureWidget, SIGNAL(configureClicked()), SIGNAL(configureClicked()));
    addWidget(mConfigureWidget);
    mStorageServiceTabWidget = new StorageServiceTabWidget;
    connect(mStorageServiceTabWidget, SIGNAL(tabCountChanged(bool)), SLOT(slotTabCountchanged(bool)));
    addWidget(mStorageServiceTabWidget);
    setCurrentWidget(mConfigureWidget);
}

StorageServiceManagerMainWidget::~StorageServiceManagerMainWidget()
{

}

StorageServiceTabWidget *StorageServiceManagerMainWidget::storageServiceTabWidget() const
{
    return mStorageServiceTabWidget;
}

void StorageServiceManagerMainWidget::slotTabCountchanged(bool hasTab)
{
    if (hasTab)
        setCurrentWidget(mStorageServiceTabWidget);
    else
        setCurrentWidget(mConfigureWidget);
}

==> kdepim-15.12.2.tar.xz: kdepim-15.12.2/storageservicemanager/storageservicemanagermainwidget.cpp <==
/*
  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "storageservicemanagermainwidget.h"
#include "storageserviceconfigurestoragewidget.h"
#include "storageservicetabwidget.h"

StorageServiceManagerMainWidget::StorageServiceManagerMainWidget(QWidget *parent)
    : QStackedWidget(parent)
{
    mConfigureWidget = new StorageServiceConfigureStorageWidget;
    connect(mConfigureWidget, &StorageServiceConfigureStorageWidget::configureClicked, this, &StorageServiceManagerMainWidget::configureClicked);
    addWidget(mConfigureWidget);
    mStorageServiceTabWidget = new StorageServiceTabWidget;
    connect(mStorageServiceTabWidget, &StorageServiceTabWidget::tabCountChanged, this, &StorageServiceManagerMainWidget::slotTabCountchanged);
    addWidget(mStorageServiceTabWidget);
    setCurrentWidget(mConfigureWidget);
}

StorageServiceManagerMainWidget::~StorageServiceManagerMainWidget()
{

}

StorageServiceTabWidget *StorageServiceManagerMainWidget::storageServiceTabWidget() const
{
    return mStorageServiceTabWidget;
}

void StorageServiceManagerMainWidget::slotTabCountchanged(bool hasTab)
{
    if (hasTab) {
        setCurrentWidget(mStorageServiceTabWidget);
    } else {
        setCurrentWidget(mConfigureWidget);
    }
}
